# eric7.Plugins.VcsPlugins.vcsMercurial.HgRemoveSubrepositoriesDialog

Module implementing a dialog to remove sub-repositories.

### Global Attributes

None

### Classes

HgRemoveSubrepositoriesDialog | Class implementing a dialog to remove sub-repositories.

### Functions

None

## HgRemoveSubrepositoriesDialog

Class implementing a dialog to remove sub-repositories.

### Derived from

QDialog, Ui_HgRemoveSubrepositoriesDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgRemoveSubrepositoriesDialog | Constructor
getData | Public method to retrieve the data.
on_removeButton_clicked | Private slot handling the removal of the selected entries.
on_subrepositories_itemSelectionChanged | Private slot handling the selection of entries.

### Static Methods

None

#### HgRemoveSubrepositoriesDialog (Constructor)

HgRemoveSubrepositoriesDialog(subrepositories, parent=None)

Constructor

subrepositories (list of str)
  list of sub-repository entries
parent (QWidget)
  reference to the parent widget

#### HgRemoveSubrepositoriesDialog.getData

getData()

Public method to retrieve the data.

Return:
  tuple giving the remaining sub-repositories, the removed ones and a flag indicating to delete the removed ones from disc

Return Type:
  tuple of (list of str, list of str, bool)

#### HgRemoveSubrepositoriesDialog.on_removeButton_clicked

on_removeButton_clicked()

Private slot handling the removal of the selected entries.

#### HgRemoveSubrepositoriesDialog.on_subrepositories_itemSelectionChanged

on_subrepositories_itemSelectionChanged()

Private slot handling the selection of entries.

Up